@@ -22,14 +22,14 @@
 
 import string
 from collections import Counter
-from typing import Dict, Union, Tuple, List
+from typing import Any, Dict, Union, Tuple, List
 
 
 def is_pangram(sentence: str, alphabet: str = string.ascii_lowercase) -> bool:
 	'''Checks if inputed string is pangram (A pangram is a sentence using every letter of a given alphabet at least once.)
 	- is_pangram('Watch "Jeopardy!", Alex Trebek\'s fun TV quiz game.') -> True
 	- is_pangram('Hello beautiful world!') -> False'''
-	#Checking if created set contains all characters from our alphabet, and returning bool
+	#Checking if created set contains all characters from alphabet, and returning bool
 	return all(char in set(sentence.lower()) for char in alphabet.lower())
 
 def is_heterogram(sentence: str) -> bool:
@@ -42,9 +42,9 @@ def is_anagram(first_word: str, second_word: str) -> bool:
 	'''Checks if inputed string is an anagram (Anagram is a string that contain all letters from other string.)
 	- is_anagram("Listen", "Silent") -> True
 	- is_anagram("123", ("1234")) -> False'''
-	return dict(Counter(first_word.replace(" ", "").lower())) == dict(Counter(second_word.replace(" ", "").lower()))
+	return Counter(first_word.replace(" ", "").lower()) == Counter(second_word.replace(" ", "").lower())
 
-def is_palindrome(obj: Union[List[Union[str, int]], str, int, Tuple[Union[str, int]]]) -> bool:
+def is_palindrome(obj: Union[str, int, List[Any], Tuple[Any]]) -> bool:
 	'''Checks if inputed string is a palindrome (A palindrome is a word, number, phrase,
 	or other sequence of characters which reads the same backward as forward, such as madam or racecar.)
 		Takes Built-in Data Types (list, tuple, str, int)
@@ -52,38 +52,34 @@ def is_palindrome(obj: Union[List[Union[str, int]], str, int, Tuple[Union[str, i
 	the same backward as forward, such as madam or racecar.)
 	- is_palindrome("radar") -> True
 	- is_palindrome("word") -> False'''
-	
+	try:
+		return obj == obj[::-1]
+	except TypeError:
+		pass
+	if type(obj) == int:
+		return str(obj).replace(".", "") == str(obj)[::-1].replace(".", "")
 	if type(obj) == dict:
 		raise ValueError("Dictionaries don't support duplicate keys. So it can't be palindrome.")
-	if type(obj) == set:
-		raise ValueError("A set does not hold duplicate items. So it can't be palindrome.")
-	
-	# If object is str or List[str] or List[int] or List[str, int] or Tuple[...]
-	try:
-		obj = [x if type(x) == int else x.lower() for x in obj]
-		return obj == obj[::-1]
-	# If object is int
-	except TypeError:
-		return str(obj) == str(obj)[::-1]
+	elif type(obj) == set and len(obj) == 1:
+		return True # If set contains only 1 element it's palindrome.
+	elif type(obj) == set:
+		raise ValueError("A set does not hold duplicate items. It can be palindrome, if there is only one element.")
 
 def is_tautogram(sentence: str) -> bool:
 	'''Checks if inputed string is a tautogram (A tautogram is a text in which all words start with the same letter.)
 	- is_tautogram("Crazy cat, cute, cuddly") -> True
 	- is_tautogram("Crazy mouse, cute, cuddly") -> False'''
-	list_sentence = sentence.lower().split(" ")
-	def __first_char(_list: List[str]):
+
+	words = sentence.lower().split() # Creating list of words 
+
+	def __first_char(_list: List[str]): # Returns first alphabetic character from List[str]
 		for word in _list:
-			for char in word:
-				if char.isalpha():
-					return char
-	first_character = __first_char(list_sentence)
-	for word in list_sentence:
-		for char in word:
-			if char.isalpha():
-				if char != first_character:
-					return False
-				break
-	return True
+			if word[0].isalpha():
+				return word[0]
+
+	first_character = __first_char(words)
+
+	return all([False for word in words if word[0].isalpha() and word[0] != first_character])
 
 def is_binary(obj: Union[str, int]) -> bool:
 	'''Checks if given string or int is binary number
@@ -112,7 +108,8 @@ def count_words(sentence: str) -> int:
 	- count_words("This is me") -> 3'''
 	if sentence:
 		return len(sentence.split())
-	else: return 0 # If sentence is empty returns 0
+	else:
+		return 0
 
 class Levenshtein():
 	'''This class contains functionts that calculates the Levenshtein distance between two strings.
